ripen_person_course

Function ripen_person_course 

pub fn ripen_person_course(
    working: &mut WorkingSet,
    student_number: &str,
    course_code: &str,
    now: DateTime<Utc>,
)
Moves every ripe submission of this person and course. Persisted wherever it is evaluated, or the next read contradicts this one.